==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Select/SelectRectangle/ts/SelectRectangle_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>SelectRectangle</name>
    <message>
        <location filename="../SelectRectangle.js" line="+73"/>
        <source>First corner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Second corner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SelectRectangle.ui" line="+17"/>
        <source>Mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Replace the current selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+16"/>
        <location line="+20"/>
        <location line="+20"/>
        <location line="+20"/>
        <source>SelectionMode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-53"/>
        <source>Add to the current selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Subtract from the current selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Intersect with the current selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Cross Selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SelectRectangleInit.js" line="+2"/>
        <source>(De-)Select &amp;Rectangular Area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>(De-)Select all entities inside a rectangle</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Select/SelectRectangle/ts/SelectRectangle_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>SelectRectangle</name>
    <message>
        <location filename="../SelectRectangle.js" line="+73"/>
        <source>First corner</source>
        <translation>První roh</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Second corner</source>
        <translation>Druhý roh</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Done</source>
        <translation>Dokončeno</translation>
    </message>
    <message>
        <location filename="../SelectRectangle.ui" line="+17"/>
        <source>Mode:</source>
        <translation>Režim:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Replace the current selection</source>
        <translation>Nahradit aktuální výběr</translation>
    </message>
    <message>
        <location line="+16"/>
        <location line="+20"/>
        <location line="+20"/>
        <location line="+20"/>
        <source>SelectionMode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-53"/>
        <source>Add to the current selection</source>
        <translation>Přidat k aktuálnímu výběru</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Subtract from the current selection</source>
        <translation>Ubrat z aktuálního výběru</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Intersect with the current selection</source>
        <translation>Průnik s aktuálním výběrem</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Cross Selection</source>
        <translation>Křížový výběr</translation>
    </message>
    <message>
        <location filename="../SelectRectangleInit.js" line="+2"/>
        <source>(De-)Select &amp;Rectangular Area</source>
        <translation>(Ne-)Vybrat &amp;obdélníkem</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>(De-)Select all entities inside a rectangle</source>
        <translation>(Ne-)Vybrat všechny objekty v obdélníku</translation>
    </message>
</context>
</TS>
